## Summary
<!-- 1-2 sentence overview of changes -->

## Changes
-

## Testing
- [ ] All tests pass (`pytest tests/ -v`)
- [ ] New tests added for new functionality
- [ ] Lint passes (`ruff check src/ tests/`)

## Type
- [ ] Feature
- [ ] Bug fix
- [ ] Refactor
- [ ] Templates
- [ ] Tests
- [ ] Docs
